/*
 * Sonar, open source software quality management tool.
 * Copyright (C) 2008-2011 SonarSource
 * mailto:contact AT sonarsource DOT com
 *
 * Sonar is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * Sonar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sonar; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02
 */
package org.sonar.plugins.clover;

import org.sonar.api.Plugin;
import org.sonar.api.Properties;
import org.sonar.api.Property;

import java.util.Arrays;
import java.util.List;

@Properties({
    @Property(
        key = CloverConstants.LICENSE_PROPERTY,
        name = "License",
        description = "You can obtain a free 30 day evaluation license or purchase a commercial license at <a href='http://my.atlassian.com'>http://my.atlassian.com</a>.",
        project = true, global = true),
    @Property(
        key = CloverConstants.REPORT_PATH_PROPERTY,
        name = "Report path",
        description = "Absolute or relative path to XML report file.",
        project = true, global = true),
    @Property(
        key = CloverConstants.VERSION_PROPERTY,
        name = "Clover version",
        description = "Override the Clover version to use. Default value is read from pom, else " + CloverConstants.DEFAULT_VERSION,
        project = true, global = true) })
public class CloverPlugin implements Plugin {

  public String getKey() {
    return "clover";
  }

  public String getName() {
    return "Clover";
  }

  public String getDescription() {
    return "Clover measures code coverage generated by system tests, functional tests or unit tests, allowing to improve test quality and find bugs sooner. You can find more by going to the <a href='http://www.atlassian.com/software/clover'>Atlassian Clover web site</a>.";
  }

  public List getExtensions() {
    return Arrays.asList(CloverMavenPluginHandler.class, CloverMavenInitializer.class, CloverSensor.class);
  }
}
